@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Osmo Salomaa
+# Copyright (C) 2006,2009 Osmo Salomaa
 #
 # This file is part of Gaupol.
 #
@@ -15,13 +15,19 @@
 # Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
 import gaupol
-import urllib
+import urllib2
 
 
 class TestModule(gaupol.TestCase):
 
-    def test_attributes(self):
+    def test_bug_report_url(self):
+        urllib2.urlopen(gaupol.BUG_REPORT_URL, timeout=10)
 
-        urllib.urlopen(gaupol.BUG_REPORT_URL)
-        urllib.urlopen(gaupol.HOMEPAGE_URL)
-        urllib.urlopen(gaupol.REGEX_HELP_URL)
+    def test_homepage_url(self):
+        urllib2.urlopen(gaupol.HOMEPAGE_URL, timeout=10)
+
+    def test_regex_help_url(self):
+        urllib2.urlopen(gaupol.REGEX_HELP_URL, timeout=10)
+
+    def test_wiki_url(self):
+        urllib2.urlopen(gaupol.WIKI_URL, timeout=10)
